@@ -1,10 +1,10 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
+# See LICENSE.txt for licensing terms
 
 """
-
 Scan a list of folders and find all .afm files,
 then create rst2pdf-ready font-aliases.
-
 """
 
 import os
@@ -23,12 +23,11 @@ pfbList = {}
 # Aliases defined by GhostScript, so if you use Palatino or whatever you
 # may get **something**. They are family name aliases.
 Alias = {
-    'ITC Bookman'            : 'URW Bookman L',
-    'ITC Avant Garde Gothic' : 'URW Gothic L',
-    'Palatino'               : 'URW Palladio L',
-    'New Century Schoolbook' : 'Century Schoolbook L',
-    'ITC Zapf Chancery'      : 'URW Chancery L'
-    }
+    'ITC Bookman': 'URW Bookman L',
+    'ITC Avant Garde Gothic': 'URW Gothic L',
+    'Palatino': 'URW Palladio L',
+    'New Century Schoolbook': 'Century Schoolbook L',
+    'ITC Zapf Chancery': 'URW Chancery L'}
 
 # Standard PDF fonts, so no need to embed them
 Ignored = ['Times', 'ITC Zapf Dingbats', 'Symbol', 'Helvetica', 'Courier']
@@ -48,7 +47,6 @@ def loadFonts():
     """
     if not afmList or not pfbList:
         # Find all ".afm" and ".pfb" files files
-
         def findFontFiles(_, folder, names):
             for f in os.listdir(folder):
                 if f.lower().endswith('.afm'):
@@ -59,8 +57,9 @@ def loadFonts():
         for folder in flist:
             os.path.walk(folder, findFontFiles, None)
 
-        # Now we have full afm and pbf lists, process the afm list to figure out
-        # family name weight and if it's italic or not, as well as where the
+        # Now we have full afm and pbf lists, process the
+        # afm list to figure out family name weight and if
+        # it's italic or not, as well as where the
         # matching pfb file is
 
         for afm in afmList:
@@ -90,7 +89,7 @@ def loadFonts():
             if family in Alias:
                 continue
             if baseName not in pfbList:
-                # print "Warning: afm file without matching pfb file: %s" % baseName
+                log.info("afm file without matching pfb file: %s"% baseName)
                 continue
 
             # So now we have a font we knopw we can embed.
@@ -102,17 +101,19 @@ def loadFonts():
             if bold and italic:
                 families[family][3] = fontName
             elif bold:
-                families[family][2] = fontName
-            elif italic:
                 families[family][1] = fontName
-            # FIXME: what happens if there are Demi and Medium weights? We get a random one.
+            elif italic:
+                families[family][2] = fontName
+            # FIXME: what happens if there are Demi and Medium
+            # weights? We get a random one.
             else:
                 families[family][0] = fontName
 
 
 def findFont(fname):
     loadFonts()
-    # So now we are sure we know the families and font names. Well, return some data!
+    # So now we are sure we know the families and font
+    # names. Well, return some data!
     if fname in fonts:
         font = fonts[fname]
     else:
@@ -134,7 +135,7 @@ def findTTFont(fname):
             if not line:
                 continue
             fname, family, _, variant = line.split('"')[:4]
-            family = family.replace('"','')
+            family = family.replace('"', '')
             if family:
                 return family
         return None
@@ -150,15 +151,14 @@ def findTTFont(fname):
     def get_variants(family):
         variants = [
             get_fname(family + ":style=Roman"),
-            get_fname(family + ":style=Oblique"),
             get_fname(family + ":style=Bold"),
-            get_fname(family + ":style=Bold Oblique")
-        ]
+            get_fname(family + ":style=Oblique"),
+            get_fname(family + ":style=Bold Oblique")]
         if variants[1] == variants[0]:
             variants[1] = get_fname(family + ":style=Italic")
         if variants[3] == variants[0]:
             variants[3] = get_fname(family + ":style=Bold Italic")
-        if variants[0].endswith('.pfb') or variants[0].endswith('.gz') :
+        if variants[0].endswith('.pfb') or variants[0].endswith('.gz'):
             return None
         return variants
 
@@ -170,11 +170,13 @@ def findTTFont(fname):
 
 
 def autoEmbed(fname):
-    """Given a font name, does a best-effort of embedding said font and its variants.
+    """Given a font name, does a best-effort of embedding
+    said font and its variants.
 
     Returns a list of the font names it registered with ReportLab.
 
     """
+    log.info('Trying to embed %s'%fname)
     fontList = []
     f = findFont(fname)
     if f: # It's a Type 1 font, and we have it
@@ -188,6 +190,8 @@ def autoEmbed(fname):
         for face, name in zip(faces, family):
             fontList.append(name)
             font = pdfmetrics.Font(face, name, "WinAnsiEncoding")
+            log.info('Registering font: %s from %s'%\
+                        (face,name))
             pdfmetrics.registerFont(font)
 
         # Map the variants
@@ -200,31 +204,31 @@ def autoEmbed(fname):
         addMapping(regular, 0, 1, italic)
         addMapping(regular, 1, 0, bold)
         addMapping(regular, 1, 1, bolditalic)
+        log.info('Embedding as %s'%fontList)
         return fontList
 
     variants = findTTFont(fname)
-    if variants: # It is a TT Font and we found it using fc-match (or found *something*)
+    # It is a TT Font and we found it using fc-match (or found *something*)
+    if variants:
         for variant in variants:
             vname = os.path.basename(variant)[:-4]
             try:
-                pdfmetrics.registerFont(TTFont(vname, variant))
+                if vname not in pdfmetrics._fonts:
+                    _font=TTFont(vname, variant, validate = 1)
+                    log.info('Registering font: %s from %s'%\
+                            (vname,variant))
+                    pdfmetrics.registerFont(_font)
             except TTFError:
-                pass
+                log.error('Error registering font: %s from %s'%(vname,variant))
             else:
                 fontList.append(vname)
-        # Also register "standard" aliases for the variants
-        # for variant, name in zip(variants,
-        #      [fname+suffix for suffix in ["", "-Oblique", "-Bold", "-BoldOblique"]]):
-        #   fontList.append(name)
-        #   pdfmetrics.registerFont(TTFont(name,v ariant))
-
-        # And map them all together
         regular, bold, italic, bolditalic = [
             os.path.basename(variant)[:-4] for variant in variants]
         addMapping(regular, 0, 0, regular)
         addMapping(regular, 0, 1, italic)
         addMapping(regular, 1, 0, bold)
         addMapping(regular, 1, 1, bolditalic)
+        log.info('Embedding via findTTFont as %s'%fontList)
     return fontList
 
 
@@ -237,8 +241,6 @@ def guessFont(fname):
         2: bold
         3: bolditalic
 
-    May be useful someday.
-
     """
     if '-' not in fname:
         return fname, 0
@@ -250,7 +252,7 @@ def guessFont(fname):
         italic = 1
     if "bold" in mod or "black" in mod:
         bold = 1
-    return family, 2*bold + italic
+    return family, bold + 2*italic
 
 
 def main():
