@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
-#$HeadURL: http://rst2pdf.googlecode.com/svn/tags/0.10.1/rst2pdf/pygments_code_block_directive.py $
-#$LastChangedDate: 2009-05-16 01:46:20 +0200 (Sa, 16. Mai 2009) $
-#$LastChangedRevision: 533 $
+#$HeadURL: https://rst2pdf.googlecode.com/svn/branches/0.12/rst2pdf/pygments_code_block_directive.py $
+#$LastChangedDate: 2009-09-03 15:39:32 -0300 (Thu, 03 Sep 2009) $
+#$LastChangedRevision: 978 $
 
 # :Author: a Pygments author|contributor; Felix Wiemann; Guenter Milde
-# :Date: $Date: 2009-05-16 01:46:20 +0200 (Sa, 16. Mai 2009) $
+# :Date: $Date: 2009-09-03 15:39:32 -0300 (Thu, 03 Sep 2009) $
 # :Copyright: This module has been placed in the public domain.
 #
 # This is a merge of `Using Pygments in ReST documents`_ from the pygments_
@@ -32,9 +32,7 @@
 # ------------
 # ::
 
-
 import codecs
-
 from docutils import nodes
 from docutils.parsers.rst import directives
 
@@ -89,14 +87,17 @@ class DocutilsInterface(object):
     def lex(self):
         # Get lexer for language (use text as fallback)
         try:
-            lexer = get_lexer_by_name(self.language)
+            if self.language and unicode(self.language).lower() <> 'none':
+                lexer = get_lexer_by_name(self.language)
+            else:
+                lexer = get_lexer_by_name('text')
         except ValueError:
-            log.info( "no pygments lexer for %s, using 'text'" % self.language)
+            log.info("no pygments lexer for %s, using 'text'" \
+                % self.language)
             # what happens if pygment isn't present ?
             lexer = get_lexer_by_name('text')
         return pygments.lex(self.code, lexer)
 
-
     def join(self, tokens):
         """join subsequent tokens of same token-type
         """
@@ -233,15 +234,14 @@ def code_block_directive(name, arguments, options, content, lineno,
 
 code_block_directive.arguments = (1, 0, 1)
 code_block_directive.content = 1
-code_block_directive.options = { 'include' : directives.unchanged_required,
-                                 'start-at' : directives.unchanged_required,
-                                 'end-at' : directives.unchanged_required,
-                                 'start-after' : directives.unchanged_required,
-                                 'end-before' : directives.unchanged_required,
-                                 'linenos' : directives.unchanged,
-                                 }
+code_block_directive.options = {'include': directives.unchanged_required,
+                                'start-at': directives.unchanged_required,
+                                'end-at': directives.unchanged_required,
+                                'start-after': directives.unchanged_required,
+                                'end-before': directives.unchanged_required,
+                                'linenos': directives.unchanged,
+                                }
 
-directives.register_directive('code-block', code_block_directive)
 
 
 # .. _doctutils: http://docutils.sf.net/
