@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
-#$HeadURL: http://rst2pdf.googlecode.com/svn/tags/0.10.1/rst2pdf/utils.py $
-#$LastChangedDate: 2009-05-16 01:46:20 +0200 (Sa, 16. Mai 2009) $
-#$LastChangedRevision: 533 $
+# See LICENSE.txt for licensing terms
+#$HeadURL: https://rst2pdf.googlecode.com/svn/branches/0.12/rst2pdf/utils.py $
+#$LastChangedDate: 2009-09-09 13:22:19 -0300 (Wed, 09 Sep 2009) $
+#$LastChangedRevision: 1009 $
 
 import shlex
 
 from reportlab.platypus import Spacer
 
 from flowables import *
+import flowables
+from styles import adjustUnits
+from log import log
 
-
-def parseRaw (data):
+def parseRaw(data):
     """Parse and process a simple DSL to handle creation of flowables.
 
     Supported (can add others on request):
@@ -32,10 +35,25 @@ def parseRaw (data):
                 elements.append(MyPageBreak())
             else:
                 elements.append(MyPageBreak(tokens[1]))
-        if command == 'Spacer':
-            elements.append(Spacer(int(tokens[1]), int(tokens[2])))
-        if command == 'Transition':
+        elif command == 'EvenPageBreak':
+            if len(tokens) == 1:
+                elements.append(MyPageBreak(breakTo='even'))
+            else:
+                elements.append(MyPageBreak(tokens[1],breakTo='even'))
+        elif command == 'OddPageBreak':
+            if len(tokens) == 1:
+                elements.append(MyPageBreak(breakTo='odd'))
+            else:
+                elements.append(MyPageBreak(tokens[1],breakTo='odd'))
+        elif command == 'Spacer':
+            elements.append(Spacer(adjustUnits(tokens[1]), 
+                adjustUnits(tokens[2])))
+        elif command == 'Transition':
             elements.append(Transition(*tokens[1:]))
+        elif command == 'SetPageCounter':
+            elements.append(flowables.PageCounter(*tokens[1:]))
+        else:
+            log.error('Unknown command %s in raw pdf directive'%command)
     return elements
 
 
